@@ -6,16 +6,17 @@ if False:  # MYPY
 
 _package_data = dict(
     full_package_name='ruamel.yaml',
-    version_info=(0, 18, 15),
-    __version__='0.18.15',
-    version_timestamp='2025-08-19 12:01:38',
+    version_info=(0, 19, 1),
+    __version__='0.19.1',
+    version_timestamp='2026-01-02 17:17:31',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     description='ruamel.yaml is a YAML parser/emitter that supports roundtrip preservation of comments, seq/map flow style, and map key order',  # NOQA
     entry_points=None,
     since=2014,
     extras_require={
-        ':platform_python_implementation=="CPython" and python_version<"3.14"': ['ruamel.yaml.clib>=0.2.7'],  # NOQA
+        'oldlibyaml' : ['ruamel.yaml.clib; platform_python_implementation=="CPython"'],  # NOQA
+        'libyaml' : ['ruamel.yaml.clibz>=0.3.7; platform_python_implementation=="CPython"'],  # NOQA
         'jinja2': ['ruamel.yaml.jinja2>=0.2'],
         'docs': ['ryd', 'mercurial>5.7'],
     },
@@ -32,7 +33,7 @@ _package_data = dict(
         fl8excl='_test/lib,branch_default',
     ),
     # universal=True,
-    supported=[(3, 8)],  # minimum
+    supported=[(3, 9)],  # minimum
 )  # type: Dict[Any, Any]
 
 
@@ -45,5 +46,6 @@ try:
     __with_libyaml__ = True
 except (ImportError, ValueError):  # for Jython
     __with_libyaml__ = False
+    __yaml_lib = None
 
 from ruamel.yaml.main import *  # NOQA
